@@ -3,11 +3,11 @@ setVectorSeed <- function(vseed)
     RNGkind("Mersenne-Twister")
     stopifnot(.Random.seed[1] %% 100 == 3)
     stopifnot(.Random.seed[2] == 624)
-    .Random.seed[3:626] <<- getVectorSeed(vseed, 624)
+    .Random.seed[3:626] <<- generateInitialization(vseed, 624)
     invisible(NULL)
 }
 
-getVectorSeed <- function(vseed, m)
+generateInitialization <- function(vseed, m)
 {
     if (any(vseed != floor(vseed))) stop("Vector seed should have integer components")
     if (any(vseed < 0 | vseed >= 2^32)) stop("Vector seed should have components in [0, 2^32-1]")
